/*
 * skillchains-db.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains JS Library.
 *
 * The FFXI Skillchains JS Library is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains JS Library is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains JS Library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * This file defines the database of skills and avatars.
 */

// Define the various elements

var EARTH = new Element(getLocalString("earth"), "earth");
var THUNDER = new Element(getLocalString("thunder"), "thunder");
var WATER = new Element(getLocalString("water"), "water");
var FIRE = new Element(getLocalString("fire"), "fire");
var ICE = new Element(getLocalString("ice"), "ice");
var WIND = new Element(getLocalString("wind"), "wind");
var LIGHT = new Element(getLocalString("light"), "light");
var DARK = new Element(getLocalString("dark"), "dark");

// NOTE: These are not *really* elements.  They mark the various Ultimate
// Renkeis.  Certain weapon skills, instead of having an element, form
// the ultimate renkei.  These mark those weapon skills.

var UE_FRAGMENTATION = new Element(getLocalString("ue.fragmentation"), "ufragmentation");
var UE_FUSION = new Element(getLocalString("ue.fusion"), "ufusion");
var UE_GRAVITATION = new Element(getLocalString("ue.gravitation"), "ugravitation");
var UE_DISTORTION = new Element(getLocalString("ue.distortion"), "udistortion");

// Create the chains, now

// Level 1 chains:
var SCISSION = new Chain(getLocalString("scission"), "scission", 1, EARTH);
var IMPACTION = new Chain(getLocalString("impaction"), "impaction", 1, THUNDER);
var REVERBERATION = new Chain(getLocalString("reverberation"), "reverberation", 1, WATER);
var LIQUEFACTION = new Chain(getLocalString("liquefaction"), "liquefaction", 1, FIRE);
var INDURATION = new Chain(getLocalString("induration"), "induration", 1, ICE);
var DETONATION = new Chain(getLocalString("detonation"), "detonation", 1, WIND);
var TRANSFIXION = new Chain(getLocalString("transfixion"), "transfixion", 1, LIGHT);
var COMPRESSION = new Chain(getLocalString("compression"), "compression", 1, DARK);

// Level 2 chains:
var GRAVITATION = new Chain(getLocalString("gravitation"), "gravitation", 2, DARK, EARTH);
var DISTORTION = new Chain(getLocalString("distortion"), "distortion", 2, WATER, ICE);
var FUSION = new Chain(getLocalString("fusion"), "fusion", 2, FIRE, LIGHT);
var FRAGMENTATION = new Chain(getLocalString("fragmentation"), "fragmentation", 2, THUNDER, WIND);

// Level 3 chains:

var ULTIMATE_LIGHT = new Chain(getLocalString("ultimate.light"), "ultlight", 3, FIRE, LIGHT, THUNDER, WIND);
var ULTIMATE_DARKNESS = new Chain(getLocalString("ultimate.darkness"), "ultdark", 3, EARTH, DARK, WATER, ICE);

// Link the elements now to describe how chains can be formed

EARTH.addChain(REVERBERATION, WATER);
EARTH.addChain(DETONATION, WIND);
EARTH.addChain(LIQUEFACTION, FIRE);
// NOTE: only when coming from Distortion
EARTH.addChain(FUSION, UE_FUSION, DISTORTION);
// NOTE: only when coming from Distortion
EARTH.addChain(ULTIMATE_DARKNESS, UE_GRAVITATION, DISTORTION);
THUNDER.addChain(LIQUEFACTION, FIRE);
THUNDER.addChain(DETONATION, WIND);
// NOTE: only when coming from Fusion
THUNDER.addChain(GRAVITATION, UE_GRAVITATION, FUSION);
// NOTE: only when coming from Fusion
THUNDER.addChain(ULTIMATE_LIGHT, UE_FRAGMENTATION, FUSION);
WATER.addChain(INDURATION, ICE);
WATER.addChain(IMPACTION, THUNDER);
// NOTE: only when coming from Fragmentation
WATER.addChain(DISTORTION, UE_DISTORTION, FRAGMENTATION);
// NOTE: only when coming from Fragmentation
WATER.addChain(ULTIMATE_LIGHT, UE_FUSION, FRAGMENTATION);
FIRE.addChain(SCISSION, EARTH);
FIRE.addChain(FUSION, THUNDER);
ICE.addChain(FRAGMENTATION, WATER);
ICE.addChain(IMPACTION, THUNDER);
ICE.addChain(COMPRESSION, DARK);
WIND.addChain(SCISSION, EARTH);
WIND.addChain(GRAVITATION, DARK);
LIGHT.addChain(REVERBERATION, WATER);
LIGHT.addChain(DISTORTION, EARTH);
LIGHT.addChain(COMPRESSION, DARK);
DARK.addChain(DETONATION, WIND);
DARK.addChain(TRANSFIXION, LIGHT);
// NOTE: only when coming from Gravitation
DARK.addChain(FRAGMENTATION, UE_FRAGMENTATION, GRAVITATION);
// NOTE: only when coming from Gravitation
DARK.addChain(ULTIMATE_DARKNESS, UE_DISTORTION, GRAVITATION);

UE_FUSION.addChain(GRAVITATION, UE_GRAVITATION);
UE_FUSION.addChain(ULTIMATE_LIGHT, UE_FRAGMENTATION);
UE_FRAGMENTATION.addChain(DISTORTION, UE_DISTORTION);
UE_FRAGMENTATION.addChain(ULTIMATE_LIGHT, UE_FUSION);
UE_DISTORTION.addChain(FUSION, UE_FUSION);
UE_DISTORTION.addChain(ULTIMATE_DARKNESS, UE_GRAVITATION);
UE_GRAVITATION.addChain(FRAGMENTATION, UE_FRAGMENTATION);
UE_GRAVITATION.addChain(ULTIMATE_DARKNESS, UE_DISTORTION);

// Create the jobs:

var WARRIOR = new Job(getLocalString("warrior"), getLocalString("warrior.abrv"));
var THIEF = new Job(getLocalString("thief"), getLocalString("thief.abrv"));
var MONK = new Job(getLocalString("monk"), getLocalString("monk.abrv"));
var RED_MAGE = new Job(getLocalString("red.mage"), getLocalString("red.mage.abrv"));
var WHITE_MAGE = new Job(getLocalString("white.mage"), getLocalString("white.mage.abrv"));
var BLACK_MAGE = new Job(getLocalString("black.mage"), getLocalString("black.mage.abrv"));
var BARD = new Job(getLocalString("bard"), getLocalString("bard.abrv"));
var BEASTMASTER = new Job(getLocalString("beastmaster"), getLocalString("beastmaster.abrv"));
var DARK_KNIGHT = new Job(getLocalString("dark.knight"), getLocalString("dark.knight.abrv"));
var DRAGOON = new Job(getLocalString("dragoon"), getLocalString("dragoon.abrv"));
var NINJA = new Job(getLocalString("ninja"), getLocalString("ninja.abrv"));
var PALADIN = new Job(getLocalString("paladin"), getLocalString("paladin.abrv"));
var RANGER = new Job(getLocalString("ranger"), getLocalString("ranger.abrv"));
var SAMURAI = new Job(getLocalString("samurai"), getLocalString("samurai.abrv"));
var SUMMONER = new Job(getLocalString("summoner"), getLocalString("summoner.abrv"));

// OK, next the weapon classes...

var ARCHERY = new Weapon(getLocalString("archery"), [RANGER], [RANGER]);
var BOW = ARCHERY; // alias
var AXE = new Weapon(getLocalString("axe"), [WARRIOR, BEASTMASTER, DARK_KNIGHT], [WARRIOR, BEASTMASTER]);
var CLUB = new Weapon(getLocalString("club"), [WARRIOR, PALADIN, WHITE_MAGE, DARK_KNIGHT, SAMURAI], [WHITE_MAGE]);
var DAGGER = new Weapon(getLocalString("dagger"), [THIEF, RED_MAGE, BARD, RANGER, NINJA], [THIEF]);
var GREAT_AXE = new Weapon(getLocalString("great.axe"), [WARRIOR, DARK_KNIGHT], [WARRIOR]);
var GREAT_KATANA = new Weapon(getLocalString("great.katana"), null, [SAMURAI]);
var GREAT_SWORD = new Weapon(getLocalString("great.sword"), [WARRIOR, PALADIN, DARK_KNIGHT], [PALADIN, DARK_KNIGHT]);
var HAND_TO_HAND = new Weapon(getLocalString("hand.to.hand"), [MONK], [MONK]);
var KATANA = new Weapon(getLocalString("katana"), null, [NINJA]);
var MARKSMANSHIP = new Weapon(getLocalString("marksmanship"), [RANGER], [RANGER]);
var GUN = MARKSMANSHIP; // alias
var SCYTHE = new Weapon(getLocalString("scythe"), [WARRIOR, DARK_KNIGHT], [DARK_KNIGHT]);
var POLEARM = new Weapon(getLocalString("polearm"), [WARRIOR, PALADIN, DRAGOON], [DRAGOON]);
var SPEAR = POLEARM; // alias
var STAFF = new Weapon(getLocalString("staff"), [PALADIN, MONK, WARRIOR, WHITE_MAGE], null);
var SWORD = new Weapon(getLocalString("sword"), [PALADIN, WARRIOR, DARK_KNIGHT], [PALADIN]);

// Now the avatars (for when S-E adds avatars)
var CARBUNCLE = new Weapon(getLocalString("carbuncle"));
var GARUDA = new Weapon(getLocalString("garuda"));
var IFRIT = new Weapon(getLocalString("ifrit"));
var LEVIATHAN = new Weapon(getLocalString("leviathan"));
var RAMUH = new Weapon(getLocalString("ramuh"));
var SHIVA = new Weapon(getLocalString("shiva"));
var TITAN = new Weapon(getLocalString("titan"));
var FENRIR = new Weapon(getLocalString("fenrir"));

// Now, the skills themselves!
//
// NOTE: This skill list has NOT been verified.
// It is currently based on the list of weapon skills compiled in
// the Weapon Skill FAQ on Gamefaqs:
// <http://db.gamefaqs.com/computer/doswin/file/final_fantasy_xi_weapon_skillchain.txt>

// ARCHERY:
//  EX/SP - RNG
ARCHERY.addSkill(new WeaponSkill(getLocalString("flaming.arrow"), 10, WS_EX, FIRE, LIGHT)); // EX
ARCHERY.addSkill(new WeaponSkill(getLocalString("piercing.arrow"), 40, WS_EX, WATER, LIGHT)); // EX
ARCHERY.addSkill(new WeaponSkill(getLocalString("dulling.arrow"), 80, WS_EX, FIRE, LIGHT)); // EX
ARCHERY.addSkill(new WeaponSkill(getLocalString("sidewinder"), 175, WS_EX, WATER, LIGHT, WIND)); // EX
ARCHERY.addSkill(new WeaponSkill(getLocalString("blast.arrow"), 200, WS_SP, ICE, LIGHT)); // SP
ARCHERY.addSkill(new WeaponSkill(getLocalString("arching.arrow"), 225, WS_SP, UE_FUSION)); // SP
ARCHERY.addSkill(new WeaponSkill(getLocalString("emperial.arrow"), 250, WS_EX, UE_FUSION, LIGHT)); // EX
// AXE:
//  EX - WAR/BST/DRK
//  SP - WAR/BST
AXE.addSkill(new WeaponSkill(getLocalString("raging.axe"), 10, WS_NORMAL, WIND, THUNDER));
AXE.addSkill(new WeaponSkill(getLocalString("smash.axe"), 40, WS_NORMAL, ICE, WATER));
AXE.addSkill(new WeaponSkill(getLocalString("gale.axe"), 70, WS_NORMAL, WIND));
AXE.addSkill(new WeaponSkill(getLocalString("avalanche.axe"), 100, WS_NORMAL, EARTH, THUNDER));
AXE.addSkill(new WeaponSkill(getLocalString("spinning.axe"), 150, WS_EX, FIRE, EARTH, THUNDER)); // EX
AXE.addSkill(new WeaponSkill(getLocalString("rampage"), 175, WS_NORMAL, EARTH));
AXE.addSkill(new WeaponSkill(getLocalString("calamity"), 200, WS_SP, EARTH, THUNDER)); // SP
AXE.addSkill(new WeaponSkill(getLocalString("mistral.axe"), 225, WS_SP, UE_FUSION)); // SP
AXE.addSkill(new WeaponSkill(getLocalString("decimation"), 240, WS_NORMAL, UE_FUSION, WATER));
// CLUB:
//  EX - WAR/PLD/WHM/DRK/SAM
//  SP - WHM
CLUB.addSkill(new WeaponSkill(getLocalString("shining.strike"), 10, WS_NORMAL, THUNDER));
CLUB.addSkill(new WeaponSkill(getLocalString("seraph.strike"), 40, WS_EX, THUNDER)); // EX
CLUB.addSkill(new WeaponSkill(getLocalString("brainshaker"), 70, WS_NORMAL, WATER));
CLUB.addSkill(new WeaponSkill(getLocalString("star.light"), 100, WS_NORMAL));
CLUB.addSkill(new WeaponSkill(getLocalString("moon.light"), 100, WS_EX)); // EX
CLUB.addSkill(new WeaponSkill(getLocalString("skullbreaker"), 150, WS_NORMAL, ICE, WATER));
CLUB.addSkill(new WeaponSkill(getLocalString("true.strike"), 175, WS_NORMAL, WIND, THUNDER));
CLUB.addSkill(new WeaponSkill(getLocalString("judgment"), 200, WS_EX, THUNDER)); // EX
CLUB.addSkill(new WeaponSkill(getLocalString("hexa.strike"), 220, WS_SP, UE_FUSION)); // SP
CLUB.addSkill(new WeaponSkill(getLocalString("black.halo"), 230, WS_SP, UE_FRAGMENTATION, DARK)); // SP
// DAGGER:
//  EX - THF/RDM/BRD/RNG/NIN
//  SP - THF
DAGGER.addSkill(new WeaponSkill(getLocalString("wasp.sting"), 10, WS_NORMAL, EARTH));
DAGGER.addSkill(new WeaponSkill(getLocalString("gust.slash"), 40, WS_NORMAL, WIND));
DAGGER.addSkill(new WeaponSkill(getLocalString("shadowstich"), 70, WS_NORMAL, WATER));
DAGGER.addSkill(new WeaponSkill(getLocalString("viper.bite"), 100, WS_EX, EARTH)); // EX
DAGGER.addSkill(new WeaponSkill(getLocalString("cyclone"), 125, WS_EX, WIND, THUNDER)); // EX
DAGGER.addSkill(new WeaponSkill(getLocalString("energy.steal"), 150, WS_NORMAL));
DAGGER.addSkill(new WeaponSkill(getLocalString("energy.drain"), 175, WS_EX)); // EX
DAGGER.addSkill(new WeaponSkill(getLocalString("dancing.edge"), 200, WS_SP, EARTH, WIND)); // SP
DAGGER.addSkill(new WeaponSkill(getLocalString("shark.bite"), 225, WS_SP, UE_FRAGMENTATION)); // SP
DAGGER.addSkill(new WeaponSkill(getLocalString("evisceration"), 250, WS_NORMAL, UE_FRAGMENTATION, LIGHT));
// GREAT AXE:
//  EX - WAR/DRK
//  SP - WAR
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("shield.break"), 10, WS_NORMAL, THUNDER));
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("iron.tempest"), 40, WS_NORMAL, EARTH /*, THUNDER ? */));
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("strumwind"), 70, WS_EX, WATER, EARTH)); // EX
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("armor.break"), 100, WS_NORMAL, THUNDER));
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("keen.edge"), 150, WS_NORMAL, DARK));
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("weapon.break"), 175, WS_NORMAL, THUNDER));
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("raging.rush"), 200, WS_SP, ICE, WATER)); // SP
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("full.break"), 225, WS_SP, UE_DISTORTION)); // SP
GREAT_AXE.addSkill(new WeaponSkill(getLocalString("steel.cyclone"), 240, WS_NORMAL, UE_DISTORTION, WIND));
// GREAT KATANA:
//  SP - SAM
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.enpi"), 10, WS_NORMAL, LIGHT, EARTH));
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.hobaku"), 30, WS_NORMAL, ICE));
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.goten"), 70, WS_NORMAL, LIGHT, THUNDER));
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.kagero"), 100, WS_NORMAL, FIRE));
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.jinpu"), 150, WS_NORMAL, EARTH, WIND));
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.koki"), 175, WS_NORMAL, WATER, THUNDER)); // elements may be reversed on this
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.yukikaze"), 200, WS_SP, ICE, WIND)); // SP
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.gekko"), 225, WS_SP, UE_DISTORTION, WATER)); // SP
GREAT_KATANA.addSkill(new WeaponSkill(getLocalString("tachi.kasha"), 250, WS_NORMAL, UE_FUSION, DARK));
// GREAT SWORD
//  EX - WAR/PLD/DRK
//  SP - PLD/DRK
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("hard.slash"), 10, WS_NORMAL, EARTH));
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("power.slash"), 30, WS_NORMAL, LIGHT));
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("frostbite"), 70, WS_NORMAL, ICE));
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("freezebite"), 100, WS_EX, ICE, WIND)); // EX
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("shockwave"), 150, WS_NORMAL, WATER));
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("crescent.moon"), 175, WS_NORMAL, EARTH));
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("sickle.moon"), 200, WS_SP, EARTH, THUNDER)); // SP
// The following two were listed as Gravitation
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("spinning.slash"), 225, WS_SP, UE_FRAGMENTATION)); // SP
GREAT_SWORD.addSkill(new WeaponSkill(getLocalString("ground.strike"), 250, WS_NORMAL, UE_FRAGMENTATION, UE_DISTORTION));
// HAND TO HAND
//  EX - MNK
//  SP - MNK
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("combo"), 10, WS_NORMAL, THUNDER));
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("shoulder.tackle"), 40, WS_NORMAL, WATER, THUNDER));
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("one.inch.punch"), 75, WS_EX, DARK)); // EX
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("backhand.blow"), 100, WS_NORMAL, WIND));
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("raging.fists"), 125, WS_EX, THUNDER)); // EX
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("spinning.attack"), 150, WS_NORMAL, FIRE, THUNDER));
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("howling.fist"), 200, WS_SP, LIGHT, THUNDER)); // SP
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("dragon.kick"), 225, WS_SP, UE_FRAGMENTATION)); // SP
HAND_TO_HAND.addSkill(new WeaponSkill(getLocalString("ashuran.fist"), 250, WS_SP, UE_GRAVITATION, FIRE)); // SP
// KATANA
//  SP - NIN
KATANA.addSkill(new WeaponSkill(getLocalString("blade.rin"), 10, WS_NORMAL, LIGHT));
KATANA.addSkill(new WeaponSkill(getLocalString("blade.retsu"), 30, WS_NORMAL, EARTH));
KATANA.addSkill(new WeaponSkill(getLocalString("blade.teki"), 70, WS_NORMAL, WATER));
KATANA.addSkill(new WeaponSkill(getLocalString("blade.to"), 100, WS_NORMAL, ICE, WIND));
KATANA.addSkill(new WeaponSkill(getLocalString("blade.chi"), 150, WS_NORMAL, LIGHT, THUNDER));
KATANA.addSkill(new WeaponSkill(getLocalString("blade.ei"), 175, WS_NORMAL, DARK));
KATANA.addSkill(new WeaponSkill(getLocalString("blade.jin"), 200, WS_SP, WIND, THUNDER)); // SP
KATANA.addSkill(new WeaponSkill(getLocalString("blade.ten"), 225, WS_SP, UE_GRAVITATION)); // SP
KATANA.addSkill(new WeaponSkill(getLocalString("blade.ku"), 250, WS_SP, UE_GRAVITATION, LIGHT)); // SP
// MARKSMANSHIP
//  EX - RNG
//  SP - RNG
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("hot.shot"), 10, WS_EX, FIRE, LIGHT)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("split.shot"), 40, WS_EX, WATER, LIGHT)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("sniper.shot"), 80, WS_EX, FIRE, LIGHT)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("slug.shot"), 175, WS_EX, WATER, LIGHT, WIND)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("blast.shot"), 200, WS_SP, ICE, LIGHT)); // SP
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("heavy.shot"), 225, WS_SP, UE_FUSION)); // SP
MARKSMANSHIP.addSkill(new WeaponSkill(getLocalString("detonator"), 250, WS_NORMAL, UE_FUSION, LIGHT));
// SCYTHE
//  EX - WAR/DRK
//  SP - DRK
SCYTHE.addSkill(new WeaponSkill(getLocalString("slice"), 10, WS_NORMAL, EARTH));
SCYTHE.addSkill(new WeaponSkill(getLocalString("dark.harvest"), 40, WS_NORMAL, WATER));
SCYTHE.addSkill(new WeaponSkill(getLocalString("shadow.of.death"), 70, WS_EX, ICE, WATER)); // EX
SCYTHE.addSkill(new WeaponSkill(getLocalString("nightmare.scythe"), 100, WS_NORMAL, DARK, EARTH));
SCYTHE.addSkill(new WeaponSkill(getLocalString("spinning.scythe"), 125, WS_NORMAL, WATER, EARTH));
SCYTHE.addSkill(new WeaponSkill(getLocalString("vorpal.scythe"), 150, WS_NORMAL, LIGHT, EARTH));
SCYTHE.addSkill(new WeaponSkill(getLocalString("guillotine"), 200, WS_SP, ICE)); // SP
SCYTHE.addSkill(new WeaponSkill(getLocalString("cross.reaper"), 225, WS_SP, UE_DISTORTION)); // SP
SCYTHE.addSkill(new WeaponSkill(getLocalString("spiral.hell"), 240, WS_NORMAL, UE_DISTORTION, EARTH));
// SPEAR
//  EX - WAR/PLD/DRG
//  SP - DRG
SPEAR.addSkill(new WeaponSkill(getLocalString("double.thrust"), 10, WS_NORMAL, LIGHT));
SPEAR.addSkill(new WeaponSkill(getLocalString("thunder.thrust"), 30, WS_NORMAL, LIGHT, THUNDER));
SPEAR.addSkill(new WeaponSkill(getLocalString("raiden.thrust"), 70, WS_EX, LIGHT, THUNDER)); // EX
SPEAR.addSkill(new WeaponSkill(getLocalString("leg.sweep"), 100, WS_NORMAL, THUNDER));
SPEAR.addSkill(new WeaponSkill(getLocalString("penta.thrust"), 150, WS_NORMAL, DARK));
SPEAR.addSkill(new WeaponSkill(getLocalString("vorpal.thrust"), 175, WS_NORMAL, WATER, LIGHT));
SPEAR.addSkill(new WeaponSkill(getLocalString("skewer"), 200, WS_SP, THUNDER, DARK, LIGHT)); // (Thunder was missing, possibly) SP
SPEAR.addSkill(new WeaponSkill(getLocalString("wheeling.thrust"), 225, WS_SP, UE_FUSION)); // SP
SPEAR.addSkill(new WeaponSkill(getLocalString("impulse.drive"), 240, WS_NORMAL, UE_GRAVITATION, ICE /* ? */));
// STAFF
//  EX - PLD/MNK/WAR/WHM
STAFF.addSkill(new WeaponSkill(getLocalString("heavy.swing"), 10, WS_NORMAL, THUNDER));
STAFF.addSkill(new WeaponSkill(getLocalString("rock.crusher"), 40, WS_NORMAL, THUNDER));
STAFF.addSkill(new WeaponSkill(getLocalString("earth.crusher"), 70, WS_EX, WIND, THUNDER)); // EX
STAFF.addSkill(new WeaponSkill(getLocalString("star.burst"), 100, WS_NORMAL, DARK, WATER));
STAFF.addSkill(new WeaponSkill(getLocalString("sun.burst"), 150, WS_EX, DARK, WATER)); // EX
STAFF.addSkill(new WeaponSkill(getLocalString("shell.crusher"), 175, WS_NORMAL, WIND, THUNDER));
STAFF.addSkill(new WeaponSkill(getLocalString("full.swing"), 200, WS_NORMAL, FIRE, THUNDER));
STAFF.addSkill(new WeaponSkill(getLocalString("spirit.taker"), 215, WS_NORMAL)); // Doesn't chain?  Used to be THUNDER, FIRE
STAFF.addSkill(new WeaponSkill(getLocalString("retribution"), 230, WS_NORMAL, UE_GRAVITATION, WATER));
// SWORD
//  EX - PLD/WAR/DRK
//  SP - PLD
SWORD.addSkill(new WeaponSkill(getLocalString("fast.blade"), 10, WS_NORMAL, EARTH));
SWORD.addSkill(new WeaponSkill(getLocalString("burning.blade"), 30, WS_NORMAL, FIRE));
SWORD.addSkill(new WeaponSkill(getLocalString("red.lotus.blade"), 50, WS_EX, FIRE, WIND)); // EX
SWORD.addSkill(new WeaponSkill(getLocalString("flat.blade"), 75, WS_NORMAL, THUNDER));
SWORD.addSkill(new WeaponSkill(getLocalString("shining.blade"), 100, WS_NORMAL, EARTH));
SWORD.addSkill(new WeaponSkill(getLocalString("seraph.blade"), 125, WS_EX, EARTH)); // EX
SWORD.addSkill(new WeaponSkill(getLocalString("circle.blade"), 150, WS_NORMAL, WATER, THUNDER));
SWORD.addSkill(new WeaponSkill(getLocalString("spirits.within"), 175, WS_NORMAL));
SWORD.addSkill(new WeaponSkill(getLocalString("vorpal.blade"), 200, WS_EX, EARTH, THUNDER)); // EX
SWORD.addSkill(new WeaponSkill(getLocalString("swift.blade"), 225, WS_SP, UE_GRAVITATION)); // SP
SWORD.addSkill(new WeaponSkill(getLocalString("savage.blade"), 240, WS_NORMAL, UE_FRAGMENTATION, EARTH));

// AVATAR BLOOD PACTS
// The current list of blood pacts taken from:
// <http://www.ukg.pwp.blueyonder.co.uk/avatar.htm>

CARBUNCLE.addSkill(new WeaponSkill(getLocalString("searing.light"), 1, WS_AVATAR | WS_ASTRALFLOW));
CARBUNCLE.addSkill(new WeaponSkill(getLocalString("healing.ruby"), 1, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill(getLocalString("poison.nails"), 5, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill(getLocalString("shining.ruby"), 24, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill(getLocalString("glittering.ruby"), 44, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill(getLocalString("meteorite"), 55, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill(getLocalString("healing.ruby.2"), 65, WS_AVATAR));

GARUDA.addSkill(new WeaponSkill(getLocalString("aerial.blast"), 1, WS_AVATAR | WS_ASTRALFLOW));
GARUDA.addSkill(new WeaponSkill(getLocalString("claw"), 1, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("aero.2"), 10, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("aerial.armor"), 25, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("whispering.wind"), 36, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("hastega"), 48, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("aero.4"), 60, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("predator.claw"), 70, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill(getLocalString("wind.blade"), 75, WS_AVATAR));

TITAN.addSkill(new WeaponSkill(getLocalString("rage.of.the.earth"), 1, WS_AVATAR | WS_ASTRALFLOW));
TITAN.addSkill(new WeaponSkill(getLocalString("rock.throw"), 1, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("stone.2"), 10, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("rock.buster"), 21, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("megalith.throw"), 35, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("earthen.ward"), 46, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("stone.4"), 60, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("mountain.crash"), 70, WS_AVATAR));
TITAN.addSkill(new WeaponSkill(getLocalString("ground.fury"), 75, WS_AVATAR));

SHIVA.addSkill(new WeaponSkill(getLocalString("diamond.dust"), 1, WS_AVATAR | WS_ASTRALFLOW));
SHIVA.addSkill(new WeaponSkill(getLocalString("axe.kick"), 1, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("blizzard.2"), 10, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("frost.armor"), 28, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("sleepga"), 40, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("double.slap"), 50, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("blizzard.4"), 60, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("rush"), 70, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill(getLocalString("heavenly.strike"), 75, WS_AVATAR));

IFRIT.addSkill(new WeaponSkill(getLocalString("inferno"), 1, WS_AVATAR | WS_ASTRALFLOW));
IFRIT.addSkill(new WeaponSkill(getLocalString("punch"), 1, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("fire.2"), 10, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("burning.strike"), 23, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("double.punch"), 30, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("crimson.howl"), 38, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("fire.4"), 60, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("flame.crush"), 70, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill(getLocalString("meteor.strike"), 75, WS_AVATAR));

RAMUH.addSkill(new WeaponSkill(getLocalString("judgement.bolt"), 1, WS_AVATAR | WS_ASTRALFLOW));
RAMUH.addSkill(new WeaponSkill(getLocalString("shock.strike"), 1, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("thunder.2"), 10, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("thunderspark"), 19, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("shockwave"), 31, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("lightening.armor"), 42, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("thunder.4"), 60, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("chaotic.strike"), 70, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill(getLocalString("thunder.storm"), 75, WS_AVATAR));

LEVIATHAN.addSkill(new WeaponSkill(getLocalString("tidal.wave"), 1, WS_AVATAR | WS_ASTRALFLOW));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("barracuda.dive"), 1, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("water.2"), 10, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("tail.whip"), 26, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("slowga"), 33, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("spring.water"), 47, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("water.4"), 60, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("spinning.dive"), 70, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill(getLocalString("grand.fall"), 75, WS_AVATAR));

FENRIR.addSkill(new WeaponSkill(getLocalString("rush"), 1, WS_AVATAR | WS_ASTRALFLOW));
FENRIR.addSkill(new WeaponSkill(getLocalString("moonlit.charge"), 5, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill(getLocalString("crescent.fang"), 10, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill(getLocalString("lunar.cry"), 24, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill(getLocalString("lunar.roar"), 32, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill(getLocalString("ecliptic.growl"), 43, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill(getLocalString("ecliptic.howl"), 54, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill(getLocalString("ecliptic.bite"), 65, WS_AVATAR));

// Finally, chuck all the data into a global object for easy reference.

var SkillChainDB = new Object();

SkillChainDB.jobs = [ WARRIOR, THIEF, MONK, RED_MAGE, WHITE_MAGE, BLACK_MAGE,
	BARD, BEASTMASTER, DARK_KNIGHT, DRAGOON, NINJA, PALADIN, RANGER,
	SAMURAI, SUMMONER ];
SkillChainDB.weapons = [ARCHERY, AXE, CLUB, DAGGER, GREAT_AXE, GREAT_KATANA,
	GREAT_SWORD, HAND_TO_HAND, KATANA, MARKSMANSHIP, SCYTHE, SPEAR,
	STAFF, SWORD];
SkillChainDB.avatars = [ CARBUNCLE, GARUDA, IFRIT, LEVIATHAN, RAMUH, SHIVA, TITAN, FENRIR ];
SkillChainDB.elements = [ FIRE, ICE, WIND, EARTH, THUNDER, WATER, LIGHT, DARK, UE_FRAGMENTATION, UE_FUSION, UE_GRAVITATION, UE_DISTORTION ];

// be kind and sort these for the users
SkillChainDB.jobs.sort(compareNames);
SkillChainDB.weapons.sort(compareNames);
SkillChainDB.avatars.sort(compareNames);

// Set the version number
SkillChainDB.majorVersion = 0;
SkillChainDB.minorVersion = 5;
SkillChainDB.buildVersion = 6;
