/*
 * skillchains-options.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains Tool.
 *
 * The FFXI Skillchains Tool is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains Tool is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains Tool; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Handles the setting and retrieving of options.
 */

var prefs = Components.classes["@mozilla.org/preferences-service;1"].
               getService(Components.interfaces.nsIPrefService);
prefs = prefs.getBranch("skillchains.");

var windowManager = Components.classes["@mozilla.org/appshell/window-mediator;1"].
		getService(Components.interfaces.nsIWindowMediator);

function init() {
    var showClock = false;
    var showMoon = true;
    try {
	showClock = prefs.getBoolPref("clock");
    } catch (ex) { /* don't care */ }
    try {
	showMoon = prefs.getBoolPref("moon");
    } catch (ex) { /* don't care */ }
    document.getElementById("showClock").checked = showClock;
    var moon = document.getElementById("showMoon");
    moon.checked = showMoon;
    // only can show the moon when the clock is active
    moon.disabled = ! showClock;
}

function toggleClock() {
    document.getElementById("showMoon").disabled = ! (document.getElementById("showClock").checked);
}

function acceptChanges() {
    // called to commit current changes
    var showClock = document.getElementById("showClock").checked;
    var showMoon = document.getElementById("showMoon").checked;
    prefs.setBoolPref("clock", showClock);
    prefs.setBoolPref("moon", showMoon);
    // go through windows and start/stop the clock appropriately
    var windowEnum = windowManager.getEnumerator(null);
    while (windowEnum.hasMoreElements()) {
	var win = windowEnum.getNext();
	if (win.startVanadielClock) {
	    if (showClock) {
		win.startVanadielClock(showMoon);
	    } else {
		win.stopVanadielClock();
	    }
	}
    }
}
