/*
 * skillchains-xul.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains Tool.
 *
 * The FFXI Skillchains Tool is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains Tool is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains Tool; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Controls the XUL UI.
 */

// The number of party members we display and allow
// (some future version may allow more than this, but really, there's practically
// no point in going over 6)
const MAX_PARTY_MEMBERS = 6;

// Namespace for HTML, used when generating the new output.
const HTML_NS = "";

var currentProgressCount = 0;
var totalProgressCount = 1;
var progressInterval = null;

function init() {
    var rows = document.getElementById("skill-rows");
    var row, label, textbox;
    var nonelabel = "(" + getLocalString("none") + ")";
    var anylabel = "(" + getLocalString("any") + ")";
    var exlabel = getLocalString("ex");
    var splabel = getLocalString("sp");
    for (var i = 1; i <= MAX_PARTY_MEMBERS; i++) {
	row = document.createElement("row");
	row.setAttribute("align", "center");
	label = document.createElement("label");
	label.setAttribute("id", "member" + i + "-label");
	label.setAttribute("value", getLocalString("member") + " " + i + ":");
	label.setAttribute("align", "end");
	label.setAttribute("disabled", "true");
	row.appendChild(label);
	var dropdown = document.createElement("menulist");
	dropdown.setAttribute("id", "member" + i + "-weapon");
	dropdown.setAttribute("label", nonelabel);
	dropdown.setAttribute("oncommand", "changeWeaponOrJob('" + i + "')");
	row.appendChild(dropdown);
	var menu = document.createElement("menupopup");
	dropdown.appendChild(menu);
	var item = document.createElement("menuitem");
	item.setAttribute("label", nonelabel);
	item.setAttribute("selected", "true");
	menu.appendChild(item);
	for (var w in SkillChainDB.weapons) {
	    item = document.createElement("menuitem");
	    item.setAttribute("label", SkillChainDB.weapons[w].name);
	    // set the "weapon" JavaScript property on this item
	    item.weapon = SkillChainDB.weapons[w];
	    menu.appendChild(item);
	}
	textbox = document.createElement("textbox");
	textbox.setAttribute("id", "member" + i + "-skill");
	textbox.setAttribute("value", "50");
	textbox.setAttribute("maxLength", "3");
	textbox.setAttribute("size", "3");
	textbox.setAttribute("disabled", "true");
	textbox.setAttribute("onchange", "sanitizeSkillBox(this)");
	row.appendChild(textbox);
	dropdown = document.createElement("menulist");
	dropdown.setAttribute("id", "member" + i + "-job");
	dropdown.setAttribute("label", nonelabel);
	dropdown.setAttribute("oncommand", "changeWeaponOrJob('" + i + "')");
	dropdown.setAttribute("disabled", "true");
	row.appendChild(dropdown);
	menu = document.createElement("menupopup");
	dropdown.appendChild(menu);
	var item = document.createElement("menuitem");
	item.setAttribute("label", anylabel);
	item.setAttribute("selected", "true");
	menu.appendChild(item);
	for (var j in SkillChainDB.jobs) {
	    var item = document.createElement("menuitem");
	    item.setAttribute("label", SkillChainDB.jobs[j].name);
	    // set the "job" JavaScript property on this item
	    item.job = SkillChainDB.jobs[j];
	    menu.appendChild(item);
	}
	// And again for the support job
	dropdown = document.createElement("menulist");
	dropdown.setAttribute("id", "member" + i + "-subjob");
	dropdown.setAttribute("label", nonelabel);
	dropdown.setAttribute("oncommand", "changeWeaponOrJob('" + i + "')");
	dropdown.setAttribute("disabled", "true");
	row.appendChild(dropdown);
	menu = document.createElement("menupopup");
	dropdown.appendChild(menu);
	var item = document.createElement("menuitem");
	item.setAttribute("label", nonelabel);
	item.setAttribute("selected", "true");
	menu.appendChild(item);
	for (var j in SkillChainDB.jobs) {
	    var item = document.createElement("menuitem");
	    item.setAttribute("label", SkillChainDB.jobs[j].name);
	    // set the "job" JavaScript property on this item
	    item.job = SkillChainDB.jobs[j];
	    menu.appendChild(item);
	}
	label = document.createElement("label");
	label.setAttribute("id", "member" + i + "-ex");
	label.setAttribute("value", exlabel);
	label.setAttribute("disabled", "true");
	row.appendChild(label);
	label = document.createElement("label");
	label.setAttribute("id", "member" + i + "-sp");
	label.setAttribute("value", splabel);
	label.setAttribute("disabled", "true");
	row.appendChild(label);
	rows.appendChild(row);
    }
    // One last "row" to allow setting all skills at once
    row = document.createElement("row");
    row.setAttribute("align", "center");
    label = document.createElement("label");
    label.setAttribute("value", getLocalString("all") + ":");
    label.setAttribute("align", "end");
    row.appendChild(label);
    row.appendChild(document.createElement("spacer"));
    textbox = document.createElement("textbox");
    textbox.setAttribute("id", "all-skill");
    textbox.setAttribute("value", "50");
    textbox.setAttribute("maxLength", "3");
    textbox.setAttribute("size", "3");
    textbox.setAttribute("onchange", "updateSkills()");
    row.appendChild(textbox);
    row.appendChild(document.createElement("spacer"));
    row.appendChild(document.createElement("spacer"));
    row.appendChild(document.createElement("spacer"));
    row.appendChild(document.createElement("spacer"));
    rows.appendChild(row);
    // Now add the weapon rows
    rows = document.getElementById("weapon-rows");
    row = null;
    for (var w in SkillChainDB.weapons) {
	var weapon = SkillChainDB.weapons[w];
	// create the checkbox for this weapon
	var checkbox = document.createElement("checkbox");
	checkbox.setAttribute("id", "weapon-" + w);
	checkbox.weapon = weapon;
	checkbox.setAttribute("label", weapon.name);
	if (row == null) {
	    row = document.createElement("row");
	    rows.appendChild(row);
	    row.appendChild(checkbox);
	} else {
	    row.appendChild(checkbox);
	    row = null;
	}
    }
}

function sanitizeSkillBox(box) {
    var skill = parseInt(box.value);
    var nSkill = sanitizeSkill(skill);
    // prevent infinite looping by repeatedly changing the value to the same thing
    if (box.value != nSkill)
	box.value = nSkill;
}

function sanitizeSkill(skill) {
    if (skill >= 10 && skill <= 999) {
	// Valid
	return skill;
    } else {
	if (skill > 999) {
	    // there's no point in skills above 255 (yet), but the user can feel special
	    return 999;
	} else {
	    // this grabs NaN too (since all NaN comparisons are false)
	    return 10;
	}
    }
}

function updateSkills() {
    var box = document.getElementById("all-skill");
    var skill = parseInt(box.value);
    var nSkill = sanitizeSkill(skill);
    // prevent infinite looping by repeatedly changing the value to the same thing
    if (box.value != nSkill)
	box.value = nSkill;
    // set all the other skills
    for (var i = 1; i <= MAX_PARTY_MEMBERS; i++) {
	document.getElementById("member" + i + "-skill").value = nSkill;
    }
}

function checkTabs() {
    var lookupType = document.getElementById("lookup-tabs").selectedIndex;
    if (lookupType == 0) {
	checkMembers();
    } else if (lookupType == 1) {
	checkWeapons();
    }
}

function checkMembers() {
    // count members available, disable "calculate" if none
    var disable = true;
    var count = 0;
    for (var i = 1; i <= MAX_PARTY_MEMBERS; i++) {
	if (document.getElementById("member" + i + "-weapon").selectedItem.weapon != null) {
	    count++;
	    if (count >= 2) {
		disable = false;
		break;
	    }
	}
    }
    document.getElementById("go").disabled = disable;
}

function changeWeaponOrJob(rownum) {
    // Figure out what weapon and job this has been set to
    var weapon = document.getElementById("member" + rownum + "-weapon").selectedItem.weapon;
    var jobDropdown = document.getElementById("member" + rownum + "-job");
    var job = jobDropdown.selectedItem.job;
    var subjobDropdown = document.getElementById("member" + rownum + "-subjob");
    var subjob = subjobDropdown.selectedItem.job;
    var exlabel = document.getElementById("member" + rownum + "-ex");
    var splabel = document.getElementById("member" + rownum + "-sp");
    var ex = false, sp = false;
    var disable = weapon == null;
    document.getElementById("member" + rownum + "-label").disabled = disable;
    jobDropdown.disabled = disable;
    subjobDropdown.disabled = disable;
    document.getElementById("member" + rownum + "-skill").disabled = disable;
    exlabel.disabled = disable;
    splabel.disabled = disable;
    if (weapon != null && job != null) {
	// find out if this job is EX or SP
	for (j in weapon.ex) {
	    if (job == weapon.ex[j] || subjob == weapon.ex[j]) {
		ex = true;
		break;
	    }
	}
	for (j in weapon.sp) {
	    if (job == weapon.sp[j]) {
		sp = true;
		break;
	    }
	}
	exlabel.setAttribute("value", ex ? getLocalString("ex") : "");
	splabel.setAttribute("value", sp ? getLocalString("sp") : "");
    } else {
	if (weapon == null) {
	    // no weapon, no ex/sp
	    exlabel.setAttribute("value", "");
	    splabel.setAttribute("value", "");
	} else {
	    // no job selected, use both
	    exlabel.setAttribute("value", getLocalString("ex"));
	    splabel.setAttribute("value", getLocalString("sp"));
	}
    }
}

function checkWeapons() {
    var count = 0;
    for (var w in SkillChainDB.weapons) {
	if (document.getElementById("weapon-" + w).checked) {
	    count++;
	    if (count >= 2)
		break;
	}
    }
    var chainWithSelfCheck = document.getElementById("weapon-chain-with-self");
    var calculateButton = document.getElementById("go");
    if (count == 0) {
	// disable everything
	chainWithSelfCheck.disabled = true;
	calculateButton.disabled = true;
    } else if (count == 1) {
	// force the "chain with own" checkbox to be checked and check it
	if (!chainWithSelfCheck.renew) {
	    chainWithSelfCheck.renew = true;
	    chainWithSelfCheck.lastChecked = chainWithSelfCheck.checked;
	    chainWithSelfCheck.checked = true;
	}
	chainWithSelfCheck.disabled = true;
	// allow calculations
	calculateButton.disabled = false;
    } else {
	// if the value needs to be restored, restore it
	if (chainWithSelfCheck.renew) {
	    chainWithSelfCheck.renew = false;
	    chainWithSelfCheck.checked = chainWithSelfCheck.lastChecked;
	}
	chainWithSelfCheck.disabled = false;
	calculateButton.disabled = false;
    }
}

//
// Calculates that chains and shows the results.
//
function calculateChains() {
    // disable some elements that need disabling
    document.getElementById("go").disabled = true;
    document.getElementById("lookup-tabs").disabled = true;
    // switch to the progress meter card
    document.getElementById("resultsDeck").setAttribute("selectedIndex", "1");
    // set progress to 0
    currentProgressCount = 0;
    totalProgressCount = 1;
    document.getElementById("resultsMeter").setAttribute("value", "0%");
    // Moz seems to try and be "smart" about event handlers and doesn't
    // redraw the UI until after the thing has updated, so "fork" into
    // another thread (kinda)
    progressInterval = setInterval(checkProgress, 500);
    setTimeout(runChains, 10);
}

function checkProgress() {
    document.getElementById("resultsMeter").setAttribute("value", (currentProgressCount * 100 / totalProgressCount) + "%");
}

/**
 * Finds nested chains based on currently "active" players and the weapon
 * skill last activated.
 *
 * players      - the array of players
 * curChain     - the current chain
 *
This function has been replaced
function nestPlayerChains(players, curChain) {
    var j;
    for (var i in players) {
	if (players[i].active) {
	    // look through the player's available skills
	    var curChains = players[i].findChainsFromWeaponSkill(curChain.toSkill, curChain.chain);
	    for (j in curChains) {
		// is this chain actually valid?  Can only go from one chain
		// to another chain of the same level or higher
		if (curChain.chain.level <= curChains[j].chain.level) {
		    curChain.nest(curChains[j]);
		}
	    }
	    // this player is now inactive
	    players[i].active = false;
	    // further nest chains if possible
	    for (j in curChains) {
		nestPlayerChains(players, curChains[j]);
	    }
	    // player becomes active again
	    players[i].active = true;
	}
    }
}*/

function runChains() {
    try {
	var deck = document.getElementById("resultsDeck");
	var lookupType = document.getElementById("lookup-tabs").selectedIndex;
	var hideImpossibleChains = true;
	// start actually calculating
	var chains = new Array();
	if (lookupType == 0) {
	    // create a list of players we're chaining with
	    var players = new Array();
	    //var debug = "The following players were created:";
	    for (var i = 1; i <= MAX_PARTY_MEMBERS; i++) {
		var weapon = document.getElementById("member" + i + "-weapon").selectedItem.weapon;
		if (weapon != null) {
		    // there's data here
		    var job = document.getElementById("member" + i + "-job").selectedItem.job;
		    var subjob = document.getElementById("member" + i + "-subjob").selectedItem.job;
		    var ex = false, sp = false;
		    if (job == null) {
			// when no job is selected, just report everything
			ex = true;
			sp = true;
		    } else {
			// find out if this job is EX or SP
			for (j in weapon.ex) {
			    if (job == weapon.ex[j] || subjob == weapon.ex[j]) {
				ex = true;
				break;
			    }
			}
			for (j in weapon.sp) {
			    if (job == weapon.sp[j]) {
				sp = true;
				break;
			    }
			}
		    }
		    var skill = sanitizeSkill(parseInt(document.getElementById("member" + i + "-skill").value));
		    /*debug += "\r\n - Player " + i + " uses " + weapon.name + " at skill " + skill;
		    if (ex) {
			debug += " [EX]";
		    }
		    if (sp) {
			debug += " [SP]";
		    }*/
		    // add the player
		    players.push(new Player(weapon, skill, ex, sp));
		}
	    }
	    //alert(debug);
	    if (players.length < 2) {
		alert(getLocalString("too.few.players"));
		// switch back to the help card
		deck.setAttribute("selectedIndex", "0");
		return;
	    }
	    // start calculating, based on the number of players
	    totalProgressCount = players.length * (players.length - 1);
	    var i, j, k;
	    chains = calculatePlayerChains(players);
	    // OK, start calculating by going through the players one at a time
	    /*
	    for (i in players) {
		for (j in players) {
		    // we can't chain with our self (unless we're a SAM)
		    if (i != j) {
			// look for chains we can execute
			var curChains = players[i].findChains(players[j]);
			chains = chains.concat(curChains);
			// deactivate the two players
			players[i].active = false;
			players[j].active = false;
			// go through these chains and further nest new chains.
			for (w in curChains) {
			    nestPlayerChains(players, curChains[w]);
			}
			// reactivate the two players
			players[i].active = true;
			players[j].active = true;
		    }
		}
	    }*/
	} else if (lookupType == 1) {
	    // add the weapons and look up through them
	    var weapons = new Array();
	    for (var w in SkillChainDB.weapons) {
		var checkbox = document.getElementById("weapon-" + w);
		if (checkbox.checked) {
		    weapons.push(checkbox.weapon);
		}
	    }
	    var withSelf = document.getElementById("weapon-chain-with-self").checked;
	    if (weapons.length < (withSelf ? 1 : 2)) {
		alert(getLocalString("too.few.weapons." + (withSelf ? "own" : "individual")));
		// switch back to the help card
		deck.setAttribute("selectedIndex", "0");
		return;
	    }
	    var skill = sanitizeSkill(parseInt(document.getElementById("weapon-skill-level").value));
	    // start calculating
	    currentProgressCount = 0;
	    totalProgressCount = weapons.length * (weapons.length - (withSelf ? 0 : 1));
	    var i, j;
	    for (i in weapons) {
		for (j in weapons) {
		    // can't chain with ourselves
		    if (withSelf || i != j) {
			chains = chains.concat(weapons[i].findChains(weapons[j], skill));
			currentProgressCount++;
		    }
		}
	    }
	    // go ahead and show impossible chains (ie, light and dark)
	    hideImpossibleChains = false;
	} else {
	    alert("This tab (" + lookupType + ") isn't implemented yet.  As far as I know, it doesn't exist.");
	    // switch back to the help card
	    deck.setAttribute("selectedIndex", "0");
	    return;
	}
	// we find anything?
	if (chains.length > 0) {
	    chains.sort(skillChainCompare);
	    var tree = document.getElementById("resultsChildren");
	    // remove any items currently in the tree
	    for (i = tree.childNodes.length; i > 0; i--) {
		tree.removeChild(tree.childNodes.item(i-1));
	    }
	    // create the new tree
	    createChainTree(tree, chains);
	    // ok - now switch to this part of the deck
	    deck.setAttribute("selectedIndex", "2");
	} else {
	    // nope - show the error part of the deck
	    deck.setAttribute("selectedIndex", "3");
	}
    } catch (ex) {
	alert ("An error occured while looking up chains:\r\n\r\n" + ex);
    } // finally, reenable things
    document.getElementById("go").disabled = false;
    document.getElementById("lookup-tabs").disabled = false;
    if (progressInterval != null) {
	clearInterval(progressInterval);
	progressInterval = null;
    }
}

function createChainTree(parentContainer, chains) {
    var prevChainType = null;
    var prevChain = null;
    var header = null;
    var container = null;
    var chainCount = 0;
    var item, row, cell, label, curChain;
    var arrow = getLocalString("arrow");
    for (i in chains) {
	// don't display chains twice
	if (prevChain) {
	    if (prevChain.equals(chains[i]))
		continue;
	}
	prevChain = chains[i];
	chainCount++;
	// still in the same header?
	if (chains[i].chain != prevChainType) {
	    prevChainType = chains[i].chain;
	    // build a new header
	    header = document.createElement("treeitem");
	    header.setAttribute("container", "true");
	    header.setAttribute("open", "true");
	    row = document.createElement("treerow");
	    header.appendChild(row);
	    cell = document.createElement("treecell");
	    cell.setAttribute("label", chains[i].name);
	    cell.setAttribute("src", "chrome://skillchains/skin/sc/" + chains[i].chain.icon + ".png");
	    row.appendChild(cell);
	    cell = document.createElement("treecell");
	    var element = chains[i].chain.chainElement1.name;
	    if (chains[i].chain.chainElement2 != null) {
		element = element + ", " + chains[i].chain.chainElement2.name;
		if (chains[i].chain.chainElement3 != null) {
		    element = element + ", " + chains[i].chain.chainElement3.name;
		    if (chains[i].chain.chainElement4 != null) {
			element = element + ", " + chains[i].chain.chainElement4.name;
		    }
		}
	    }
	    cell.setAttribute("label", element);
	    row.appendChild(cell);
	    parentContainer.appendChild(header);
	    container = document.createElement("treechildren");
	    header.appendChild(container);
	}
	// Add this skill chain
	createChainTreeItem(container, chains[i]);
    }
}

function createChainTreeItem(container, chain) {
    var item = document.createElement("treeitem");
    container.appendChild(item);
    row = document.createElement("treerow");
    item.appendChild(row);
    var cell = document.createElement("treecell");
    // build the label
    label = chain.fromSkill.name + " " + getLocalString("arrow") + " " + chain.toSkill.name;
    cell.setAttribute("label", label);
    row.appendChild(cell);
    cell = document.createElement("treecell");
    cell.setAttribute("label", "");
    if (chain.nextChain.length > 0) {
	chain.nextChain.sort(skillChainCompare);
	item.setAttribute("container", "true");
	item.setAttribute("open", "false");
	// now create the children
	var children = document.createElement("treechildren");
	item.appendChild(children);
	createChainTree(children, chain.nextChain);
    }
    row.appendChild(cell);
}
